@@ -109,7 +109,7 @@ void WS2812::voltChanged()
 
 void WS2812::setOut( bool state )
 {
-    m_output->sheduleState( state, 0 );
+    m_output->scheduleState( state, 0 );
     /// Simulator::self()->addEvent( 1, NULL );
 }
 
