@@ -41,8 +41,10 @@ Potentiometer::Potentiometer( QObject* parent, QString type, QString id )
              , m_resA(  id+"-resA" )
              , m_resB(  id+"-resB" )
 {
+    m_areaDial = QRectF(-11,-28 , 22, 22 );
+    m_areaComp = QRectF(-12,-4.5, 24, 12.5 );
+    m_area     = m_areaComp;
     m_graphical = true;
-    m_area = QRectF(-12,-4.5, 24, 12.5 );
 
     m_midEnode = NULL;
 
@@ -131,7 +133,7 @@ void Potentiometer::setRes( double res ) // Called when property resistance is c
     setVal( m_res1 );
 }
 
-void Potentiometer::setLinkedValue( int v, int i )
+void Potentiometer::setLinkedValue( double v, int i )
 {
     if( i ) setRes( v );
     else Dialed::setLinkedValue( v, i );
