@@ -85,24 +85,24 @@ class MAINMODULE_EXPORT Mcu : public Chip, public Linkable
 
         QString device() { return m_device; }
         bool isScripted() { return m_scripted; }
-        CpuBase* cpu() { return m_eMcu.cpu; }
+        CpuBase* cpu() { return m_eMcu.cpu(); }
 
         void reset() { m_eMcu.hardReset( true ); }
 
         bool load( QString fileName );
 
         virtual Pin* addPin( QString id, QString type, QString label,
-                             int pos, int xpos, int ypos, int angle , int length=8) override;
+                             int pos, int xpos, int ypos, int angle , int length=8, int space=0 ) override;
 
         void setScriptLinkable( ScriptCpu* l) { m_scriptLink = l; } // Called from script
 
-        virtual void setLinkedValue( int v, int i=0  ) override;
+        virtual void setLinkedValue( double v, int i=0  ) override;
         virtual void setLinkedString( QString str, int i=0 ) override;
 
         virtual QStringList getEnumUids( QString ) override;
         virtual QStringList getEnumNames( QString ) override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 
     public slots:
         void slotmain();
@@ -118,10 +118,10 @@ class MAINMODULE_EXPORT Mcu : public Chip, public Linkable
     protected:
  static Mcu* m_pSelf;
 
-        virtual void contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu );
-        virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent* event);
+        virtual void contextMenu( QGraphicsSceneContextMenuEvent* e, QMenu* m ) override;
+        virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent* e) override;
 
-        deviceType_t m_deviceType;
+        //deviceType_t m_deviceType;
 
         bool m_autoLoad;
         bool m_scripted;
